package VMOMI::DvsVmVnicNetworkResourcePoolRuntimeInfo;
use parent 'VMOMI::DynamicData';

use strict;
use warnings;

our @class_ancestors = ( 
    'DynamicData',
);

our @class_members = ( 
    ['key', undef, 0, ],
    ['name', undef, 0, 1],
    ['capacity', undef, 0, 1],
    ['usage', undef, 0, 1],
    ['available', undef, 0, 1],
    ['status', undef, 0, ],
    ['allocatedResource', 'DvsVnicAllocatedResource', 1, 1],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
